<template>
  <win-sm :title="setting.title" @close="close" :width="'800px'">
    <el-form ref="ruleForm" :model="formData" :rules="rules" class="demo-ruleForm" label-width="100px">
      <el-form-item label="盘点单名" prop="businessFormName">
        <el-input
          disabled
          v-model="formData.businessFormName"
          clearable
          maxlength="20"
          show-word-limit
          style="width: 100%"
        />
      </el-form-item>
      <el-form-item label="盘点仓库" prop="warehouseName">
        <el-select v-model="formData.warehouseId" placeholder="请选择" style="width: 100%">
          <el-option v-for="item in warehouseOptions" :key="item.id" :label="item.warehouseName" :value="item.id" />
        </el-select>
      </el-form-item>
      <el-form-item label="盘点人" prop="operatorName">
        <el-select v-model="formData.warehouseId" placeholder="请选择" style="width: 100%">
          <el-option v-for="item in operatorOptions" :key="item.id" :label="item.warehouseName" :value="item.id" />
        </el-select>
      </el-form-item>
      <el-form-item label="监盘人" prop="operatorName2">
        <el-select v-model="formData.warehouseId" placeholder="请选择" style="width: 100%">
          <el-option v-for="item in operatorOptions" :key="item.id" :label="item.warehouseName" :value="item.id" />
        </el-select>
      </el-form-item>
      <el-form-item label="备注" prop="beiz1">
        <el-input
          type="textarea"
          placeholder="请输入内容"
          v-model="formData.beiz1"
          resize="none"
          maxlength="100"
          show-word-limit
        ></el-input>
      </el-form-item>
    </el-form>
    <div slot="footer" align="center" class="dialog-footer">
      <my-button name="取消" site="form" @click="close" />
      <my-button name="保存" site="form" @click="save" />
    </div>
  </win-sm>
</template>

<script>
import { selectTenantWarehouse } from '@/api/baseSetting/finsystenant';
import winSm from '@/components/win/win-sm';
import myButton from '@/components/myButton/myButton';
import * as finsystenant from '@/api/baseSetting/finsystenant';

export default {
  components: { winSm, myButton },
  props: {
    setting: {
      type: Object,
      default: () => {},
    },
  },
  data() {
    return {
      checkAll: false,
      checkedList: [],
      warehouseOptions: [], // 仓库列表
      operatorOptions:[],
      formData: {
        code: '',
        name: '',
        status: true,
        summary: '',
      },
      rules: {
        businessFormName: [{ required: true, message: '请输入机构编号', trigger: 'blur' }],
        warehouseName: [{ required: true, message: '请选择', trigger: 'blur' }],
        operatorName: [{ required: true, message: '请选择', trigger: 'blur' }],
        operatorName2: [{ required: true, message: '请选择', trigger: 'blur' }],
      },
    };
  },
  created() {
    if (this.setting.info) {
      this.formData = Object.assign({}, JSON.parse(this.setting.info));
    }
    this.handleSelectTenantWarehouse();
  },
  methods: {
    // 获取仓库列表
    handleSelectTenantWarehouse() {
      selectTenantWarehouse().then((res) => {
        this.warehouseOptions = res;
      });
    },
    getEditInfo(id) {},
    close() {
      this.$emit('close');
    },
    save() {
      this.$refs.ruleForm.validate((valid) => {
        if (valid) {
          const params = Object.assign({}, this.formData);
          if (this.setting.id) {
            // 编辑接口
            finsystenant.edit(params).then((res) => {
              if (res) {
                this.$message.success('保存成功！');
                this.close();
                this.$emit('search');
              } else {
                this.$message.error('保存失败');
              }
            });
          } else {
            params.orgId = this.setting.orgId;
            finsystenant.add(params).then((res) => {
              if (res) {
                this.$message.success('保存成功！');
                this.close();
                this.$emit('search');
              } else {
                this.$message.error('保存失败');
              }
            });
          }
        } else {
          this.$message.error('校验未通过，请检查。');
        }
      });
    },
  },
};
</script>
